@@ -45,18 +45,23 @@ public:
   void push (Rule *);
   void push (Atom *);
   void push (Node *n);
+  Node *head ();
 
-  Node *head;
+private:
+  Node list;
   Node *tail;
 };
 
+inline Node *
+List::head ()
+{
+  return list.next;
+}
+
 inline void
 List::push (Node *n)
 {
-  if (head == 0)
-    head = n;
-  if (tail)
-    tail->next = n;
+  tail->next = n;
   tail = n;
 }
 
